package io.dekorate.kubernetes.config;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.StringBuffer;
import io.dekorate.kubernetes.annotation.ImagePullPolicy;
import java.util.Collection;
import java.lang.Object;

public class ContainerFluentImpl<A extends ContainerFluent<A>> extends io.dekorate.deps.kubernetes.api.builder.BaseFluent<A> implements ContainerFluent<A>{

    private String image;
    private String name = "";
    private List<EnvBuilder> envVars =  new ArrayList<EnvBuilder>();
    private String workingDir = "";
    private List<String> command = new ArrayList<String>();
    private List<String> arguments = new ArrayList<String>();
    private List<PortBuilder> ports =  new ArrayList<PortBuilder>();
    private List<MountBuilder> mounts =  new ArrayList<MountBuilder>();
    private ImagePullPolicy imagePullPolicy = io.dekorate.kubernetes.annotation.ImagePullPolicy.IfNotPresent;
    private ProbeBuilder livenessProbe = new ProbeBuilder();
    private ProbeBuilder readinessProbe = new ProbeBuilder();

    public ContainerFluentImpl(){
    }
    public ContainerFluentImpl(io.dekorate.kubernetes.config.Container instance){
            this.withImage(instance.getImage()); 
            this.withName(instance.getName()); 
            this.withEnvVars(instance.getEnvVars()); 
            this.withWorkingDir(instance.getWorkingDir()); 
            this.withCommand(instance.getCommand()); 
            this.withArguments(instance.getArguments()); 
            this.withPorts(instance.getPorts()); 
            this.withMounts(instance.getMounts()); 
            this.withImagePullPolicy(instance.getImagePullPolicy()); 
            this.withLivenessProbe(instance.getLivenessProbe()); 
            this.withReadinessProbe(instance.getReadinessProbe()); 
    }

    public String getImage(){
            return this.image;
    }

    public A withImage(String image){
            this.image=image; return (A) this;
    }

    public Boolean hasImage(){
            return this.image != null;
    }

    public A withNewImage(String arg1){
            return (A)withImage(new String(arg1));
    }

    public A withNewImage(StringBuilder arg1){
            return (A)withImage(new String(arg1));
    }

    public A withNewImage(StringBuffer arg1){
            return (A)withImage(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public A withEnvVars(io.dekorate.kubernetes.config.Env... envVars){
            if (this.envVars != null) {this.envVars.clear();}
            if (envVars != null) {for (io.dekorate.kubernetes.config.Env item :envVars){ this.addToEnvVars(item);}} return (A) this;
    }

    
/**
 * This method has been deprecated, please use method buildEnvVars instead.
 */
@Deprecated public io.dekorate.kubernetes.config.Env[] getEnvVars(){
            int size = envVars != null ? envVars.size() : 0;
io.dekorate.kubernetes.config.Env[] result = new io.dekorate.kubernetes.config.Env[size];
if (size == 0) {
   return result;
}
int index = 0;
for (VisitableBuilder<? extends io.dekorate.kubernetes.config.Env,?> builder : envVars) {
    result[index++]=builder.build();
}
return result;

    }

    public io.dekorate.kubernetes.config.Env[] buildEnvVars(){
            int size = envVars != null ? envVars.size() : 0;
io.dekorate.kubernetes.config.Env[] result = new io.dekorate.kubernetes.config.Env[size];
if (size == 0) {
   return result;
}
int index = 0;
for (VisitableBuilder<? extends io.dekorate.kubernetes.config.Env,?> builder : envVars) {
    result[index++]=builder.build();
}
return result;

    }

    public io.dekorate.kubernetes.config.Env buildEnvVar(int index){
            return this.envVars.get(index).build();
    }

    public io.dekorate.kubernetes.config.Env buildFirstEnvVar(){
            return this.envVars.get(0).build();
    }

    public io.dekorate.kubernetes.config.Env buildLastEnvVar(){
            return this.envVars.get(envVars.size() - 1).build();
    }

    public io.dekorate.kubernetes.config.Env buildMatchingEnvVar(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate){
            for (EnvBuilder item: envVars) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingEnvVar(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate){
            for (EnvBuilder item: envVars) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A addToEnvVars(int index,io.dekorate.kubernetes.config.Env item){
            if (this.envVars == null) {this.envVars = new ArrayList<EnvBuilder>();}
            io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("envVars").add(index >= 0 ? index : _visitables.get("envVars").size(), builder);this.envVars.add(index >= 0 ? index : envVars.size(), builder); return (A)this;
    }

    public A setToEnvVars(int index,io.dekorate.kubernetes.config.Env item){
            if (this.envVars == null) {this.envVars = new ArrayList<EnvBuilder>();}
            io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);
            if (index < 0 || index >= _visitables.get("envVars").size()) { _visitables.get("envVars").add(builder); } else { _visitables.get("envVars").set(index, builder);}
            if (index < 0 || index >= envVars.size()) { envVars.add(builder); } else { envVars.set(index, builder);}
             return (A)this;
    }

    public A addToEnvVars(io.dekorate.kubernetes.config.Env... items){
            if (this.envVars == null) {this.envVars = new ArrayList<EnvBuilder>();}
            for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("envVars").add(builder);this.envVars.add(builder);} return (A)this;
    }

    public A addAllToEnvVars(Collection<io.dekorate.kubernetes.config.Env> items){
            if (this.envVars == null) {this.envVars = new ArrayList<EnvBuilder>();}
            for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("envVars").add(builder);this.envVars.add(builder);} return (A)this;
    }

    public A removeFromEnvVars(io.dekorate.kubernetes.config.Env... items){
            for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("envVars").remove(builder);if (this.envVars != null) {this.envVars.remove(builder);}} return (A)this;
    }

    public A removeAllFromEnvVars(Collection<io.dekorate.kubernetes.config.Env> items){
            for (io.dekorate.kubernetes.config.Env item : items) {io.dekorate.kubernetes.config.EnvBuilder builder = new io.dekorate.kubernetes.config.EnvBuilder(item);_visitables.get("envVars").remove(builder);if (this.envVars != null) {this.envVars.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromEnvVars(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate){
            if (envVars == null) return (A) this;
            final Iterator<EnvBuilder> each = envVars.iterator();
            final List visitables = _visitables.get("envVars");
            while (each.hasNext()) {
              EnvBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    public Boolean hasEnvVars(){
            return envVars != null && !envVars.isEmpty();
    }

    public A addNewEnvVar(String name,String value,String secret,String configmap,String field){
            return (A)addToEnvVars(new Env(name, value, secret, configmap, field));
    }

    public ContainerFluent.EnvVarsNested<A> addNewEnvVar(){
            return new EnvVarsNestedImpl();
    }

    public ContainerFluent.EnvVarsNested<A> addNewEnvVarLike(io.dekorate.kubernetes.config.Env item){
            return new EnvVarsNestedImpl(-1, item);
    }

    public ContainerFluent.EnvVarsNested<A> setNewEnvVarLike(int index,io.dekorate.kubernetes.config.Env item){
            return new EnvVarsNestedImpl(index, item);
    }

    public ContainerFluent.EnvVarsNested<A> editEnvVar(int index){
            if (envVars.size() <= index) throw new RuntimeException("Can't edit envVars. Index exceeds size.");
            return setNewEnvVarLike(index, buildEnvVar(index));
    }

    public ContainerFluent.EnvVarsNested<A> editFirstEnvVar(){
            if (envVars.size() == 0) throw new RuntimeException("Can't edit first envVars. The list is empty.");
            return setNewEnvVarLike(0, buildEnvVar(0));
    }

    public ContainerFluent.EnvVarsNested<A> editLastEnvVar(){
            int index = envVars.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last envVars. The list is empty.");
            return setNewEnvVarLike(index, buildEnvVar(index));
    }

    public ContainerFluent.EnvVarsNested<A> editMatchingEnvVar(io.dekorate.deps.kubernetes.api.builder.Predicate<EnvBuilder> predicate){
            int index = -1;
            for (int i=0;i<envVars.size();i++) { 
            if (predicate.apply(envVars.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching envVars. No match found.");
            return setNewEnvVarLike(index, buildEnvVar(index));
    }

    public String getWorkingDir(){
            return this.workingDir;
    }

    public A withWorkingDir(String workingDir){
            this.workingDir=workingDir; return (A) this;
    }

    public Boolean hasWorkingDir(){
            return this.workingDir != null;
    }

    public A withNewWorkingDir(String arg1){
            return (A)withWorkingDir(new String(arg1));
    }

    public A withNewWorkingDir(StringBuilder arg1){
            return (A)withWorkingDir(new String(arg1));
    }

    public A withNewWorkingDir(StringBuffer arg1){
            return (A)withWorkingDir(new String(arg1));
    }

    public A withCommand(String... command){
            if (this.command != null) {this.command.clear();}
            if (command != null) {for (String item :command){ this.addToCommand(item);}} return (A) this;
    }

    public String[] getCommand(){
            //This needs to work with primitives, so we use arrays.
int size = command != null ? command.size() : 0;
String[] result = new String[size];
if (size == 0) {
   return result;
}
int index = 0;
for (String item : command) {
    result[index++]=item;
}
return result;

    }

    public A addToCommand(int index,String item){
            if (this.command == null) {this.command = new ArrayList<String>();}
            this.command.add(index, item);
            return (A)this;
    }

    public A setToCommand(int index,String item){
            if (this.command == null) {this.command = new ArrayList<String>();}
            this.command.set(index, item); return (A)this;
    }

    public A addToCommand(String... items){
            if (this.command == null) {this.command = new ArrayList<String>();}
            for (String item : items) {this.command.add(item);} return (A)this;
    }

    public A addAllToCommand(Collection<String> items){
            if (this.command == null) {this.command = new ArrayList<String>();}
            for (String item : items) {this.command.add(item);} return (A)this;
    }

    public A removeFromCommand(String... items){
            for (String item : items) {if (this.command!= null){ this.command.remove(item);}} return (A)this;
    }

    public A removeAllFromCommand(Collection<String> items){
            for (String item : items) {if (this.command!= null){ this.command.remove(item);}} return (A)this;
    }

    public Boolean hasCommand(){
            return command != null && !command.isEmpty();
    }

    public A addNewCommand(String arg1){
            return (A)addToCommand(new String(arg1));
    }

    public A addNewCommand(StringBuilder arg1){
            return (A)addToCommand(new String(arg1));
    }

    public A addNewCommand(StringBuffer arg1){
            return (A)addToCommand(new String(arg1));
    }

    public A withArguments(String... arguments){
            if (this.arguments != null) {this.arguments.clear();}
            if (arguments != null) {for (String item :arguments){ this.addToArguments(item);}} return (A) this;
    }

    public String[] getArguments(){
            //This needs to work with primitives, so we use arrays.
int size = arguments != null ? arguments.size() : 0;
String[] result = new String[size];
if (size == 0) {
   return result;
}
int index = 0;
for (String item : arguments) {
    result[index++]=item;
}
return result;

    }

    public A addToArguments(int index,String item){
            if (this.arguments == null) {this.arguments = new ArrayList<String>();}
            this.arguments.add(index, item);
            return (A)this;
    }

    public A setToArguments(int index,String item){
            if (this.arguments == null) {this.arguments = new ArrayList<String>();}
            this.arguments.set(index, item); return (A)this;
    }

    public A addToArguments(String... items){
            if (this.arguments == null) {this.arguments = new ArrayList<String>();}
            for (String item : items) {this.arguments.add(item);} return (A)this;
    }

    public A addAllToArguments(Collection<String> items){
            if (this.arguments == null) {this.arguments = new ArrayList<String>();}
            for (String item : items) {this.arguments.add(item);} return (A)this;
    }

    public A removeFromArguments(String... items){
            for (String item : items) {if (this.arguments!= null){ this.arguments.remove(item);}} return (A)this;
    }

    public A removeAllFromArguments(Collection<String> items){
            for (String item : items) {if (this.arguments!= null){ this.arguments.remove(item);}} return (A)this;
    }

    public Boolean hasArguments(){
            return arguments != null && !arguments.isEmpty();
    }

    public A addNewArgument(String arg1){
            return (A)addToArguments(new String(arg1));
    }

    public A addNewArgument(StringBuilder arg1){
            return (A)addToArguments(new String(arg1));
    }

    public A addNewArgument(StringBuffer arg1){
            return (A)addToArguments(new String(arg1));
    }

    public A withPorts(io.dekorate.kubernetes.config.Port... ports){
            if (this.ports != null) {this.ports.clear();}
            if (ports != null) {for (io.dekorate.kubernetes.config.Port item :ports){ this.addToPorts(item);}} return (A) this;
    }

    
/**
 * This method has been deprecated, please use method buildPorts instead.
 */
@Deprecated public io.dekorate.kubernetes.config.Port[] getPorts(){
            int size = ports != null ? ports.size() : 0;
io.dekorate.kubernetes.config.Port[] result = new io.dekorate.kubernetes.config.Port[size];
if (size == 0) {
   return result;
}
int index = 0;
for (VisitableBuilder<? extends io.dekorate.kubernetes.config.Port,?> builder : ports) {
    result[index++]=builder.build();
}
return result;

    }

    public io.dekorate.kubernetes.config.Port[] buildPorts(){
            int size = ports != null ? ports.size() : 0;
io.dekorate.kubernetes.config.Port[] result = new io.dekorate.kubernetes.config.Port[size];
if (size == 0) {
   return result;
}
int index = 0;
for (VisitableBuilder<? extends io.dekorate.kubernetes.config.Port,?> builder : ports) {
    result[index++]=builder.build();
}
return result;

    }

    public io.dekorate.kubernetes.config.Port buildPort(int index){
            return this.ports.get(index).build();
    }

    public io.dekorate.kubernetes.config.Port buildFirstPort(){
            return this.ports.get(0).build();
    }

    public io.dekorate.kubernetes.config.Port buildLastPort(){
            return this.ports.get(ports.size() - 1).build();
    }

    public io.dekorate.kubernetes.config.Port buildMatchingPort(io.dekorate.deps.kubernetes.api.builder.Predicate<PortBuilder> predicate){
            for (PortBuilder item: ports) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingPort(io.dekorate.deps.kubernetes.api.builder.Predicate<PortBuilder> predicate){
            for (PortBuilder item: ports) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A addToPorts(int index,io.dekorate.kubernetes.config.Port item){
            if (this.ports == null) {this.ports = new ArrayList<PortBuilder>();}
            io.dekorate.kubernetes.config.PortBuilder builder = new io.dekorate.kubernetes.config.PortBuilder(item);_visitables.get("ports").add(index >= 0 ? index : _visitables.get("ports").size(), builder);this.ports.add(index >= 0 ? index : ports.size(), builder); return (A)this;
    }

    public A setToPorts(int index,io.dekorate.kubernetes.config.Port item){
            if (this.ports == null) {this.ports = new ArrayList<PortBuilder>();}
            io.dekorate.kubernetes.config.PortBuilder builder = new io.dekorate.kubernetes.config.PortBuilder(item);
            if (index < 0 || index >= _visitables.get("ports").size()) { _visitables.get("ports").add(builder); } else { _visitables.get("ports").set(index, builder);}
            if (index < 0 || index >= ports.size()) { ports.add(builder); } else { ports.set(index, builder);}
             return (A)this;
    }

    public A addToPorts(io.dekorate.kubernetes.config.Port... items){
            if (this.ports == null) {this.ports = new ArrayList<PortBuilder>();}
            for (io.dekorate.kubernetes.config.Port item : items) {io.dekorate.kubernetes.config.PortBuilder builder = new io.dekorate.kubernetes.config.PortBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
    }

    public A addAllToPorts(Collection<io.dekorate.kubernetes.config.Port> items){
            if (this.ports == null) {this.ports = new ArrayList<PortBuilder>();}
            for (io.dekorate.kubernetes.config.Port item : items) {io.dekorate.kubernetes.config.PortBuilder builder = new io.dekorate.kubernetes.config.PortBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
    }

    public A removeFromPorts(io.dekorate.kubernetes.config.Port... items){
            for (io.dekorate.kubernetes.config.Port item : items) {io.dekorate.kubernetes.config.PortBuilder builder = new io.dekorate.kubernetes.config.PortBuilder(item);_visitables.get("ports").remove(builder);if (this.ports != null) {this.ports.remove(builder);}} return (A)this;
    }

    public A removeAllFromPorts(Collection<io.dekorate.kubernetes.config.Port> items){
            for (io.dekorate.kubernetes.config.Port item : items) {io.dekorate.kubernetes.config.PortBuilder builder = new io.dekorate.kubernetes.config.PortBuilder(item);_visitables.get("ports").remove(builder);if (this.ports != null) {this.ports.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromPorts(io.dekorate.deps.kubernetes.api.builder.Predicate<PortBuilder> predicate){
            if (ports == null) return (A) this;
            final Iterator<PortBuilder> each = ports.iterator();
            final List visitables = _visitables.get("ports");
            while (each.hasNext()) {
              PortBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    public Boolean hasPorts(){
            return ports != null && !ports.isEmpty();
    }

    public ContainerFluent.PortsNested<A> addNewPort(){
            return new PortsNestedImpl();
    }

    public ContainerFluent.PortsNested<A> addNewPortLike(io.dekorate.kubernetes.config.Port item){
            return new PortsNestedImpl(-1, item);
    }

    public ContainerFluent.PortsNested<A> setNewPortLike(int index,io.dekorate.kubernetes.config.Port item){
            return new PortsNestedImpl(index, item);
    }

    public ContainerFluent.PortsNested<A> editPort(int index){
            if (ports.size() <= index) throw new RuntimeException("Can't edit ports. Index exceeds size.");
            return setNewPortLike(index, buildPort(index));
    }

    public ContainerFluent.PortsNested<A> editFirstPort(){
            if (ports.size() == 0) throw new RuntimeException("Can't edit first ports. The list is empty.");
            return setNewPortLike(0, buildPort(0));
    }

    public ContainerFluent.PortsNested<A> editLastPort(){
            int index = ports.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last ports. The list is empty.");
            return setNewPortLike(index, buildPort(index));
    }

    public ContainerFluent.PortsNested<A> editMatchingPort(io.dekorate.deps.kubernetes.api.builder.Predicate<PortBuilder> predicate){
            int index = -1;
            for (int i=0;i<ports.size();i++) { 
            if (predicate.apply(ports.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching ports. No match found.");
            return setNewPortLike(index, buildPort(index));
    }

    public A withMounts(io.dekorate.kubernetes.config.Mount... mounts){
            if (this.mounts != null) {this.mounts.clear();}
            if (mounts != null) {for (io.dekorate.kubernetes.config.Mount item :mounts){ this.addToMounts(item);}} return (A) this;
    }

    
/**
 * This method has been deprecated, please use method buildMounts instead.
 */
@Deprecated public io.dekorate.kubernetes.config.Mount[] getMounts(){
            int size = mounts != null ? mounts.size() : 0;
io.dekorate.kubernetes.config.Mount[] result = new io.dekorate.kubernetes.config.Mount[size];
if (size == 0) {
   return result;
}
int index = 0;
for (VisitableBuilder<? extends io.dekorate.kubernetes.config.Mount,?> builder : mounts) {
    result[index++]=builder.build();
}
return result;

    }

    public io.dekorate.kubernetes.config.Mount[] buildMounts(){
            int size = mounts != null ? mounts.size() : 0;
io.dekorate.kubernetes.config.Mount[] result = new io.dekorate.kubernetes.config.Mount[size];
if (size == 0) {
   return result;
}
int index = 0;
for (VisitableBuilder<? extends io.dekorate.kubernetes.config.Mount,?> builder : mounts) {
    result[index++]=builder.build();
}
return result;

    }

    public io.dekorate.kubernetes.config.Mount buildMount(int index){
            return this.mounts.get(index).build();
    }

    public io.dekorate.kubernetes.config.Mount buildFirstMount(){
            return this.mounts.get(0).build();
    }

    public io.dekorate.kubernetes.config.Mount buildLastMount(){
            return this.mounts.get(mounts.size() - 1).build();
    }

    public io.dekorate.kubernetes.config.Mount buildMatchingMount(io.dekorate.deps.kubernetes.api.builder.Predicate<MountBuilder> predicate){
            for (MountBuilder item: mounts) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingMount(io.dekorate.deps.kubernetes.api.builder.Predicate<MountBuilder> predicate){
            for (MountBuilder item: mounts) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A addToMounts(int index,io.dekorate.kubernetes.config.Mount item){
            if (this.mounts == null) {this.mounts = new ArrayList<MountBuilder>();}
            io.dekorate.kubernetes.config.MountBuilder builder = new io.dekorate.kubernetes.config.MountBuilder(item);_visitables.get("mounts").add(index >= 0 ? index : _visitables.get("mounts").size(), builder);this.mounts.add(index >= 0 ? index : mounts.size(), builder); return (A)this;
    }

    public A setToMounts(int index,io.dekorate.kubernetes.config.Mount item){
            if (this.mounts == null) {this.mounts = new ArrayList<MountBuilder>();}
            io.dekorate.kubernetes.config.MountBuilder builder = new io.dekorate.kubernetes.config.MountBuilder(item);
            if (index < 0 || index >= _visitables.get("mounts").size()) { _visitables.get("mounts").add(builder); } else { _visitables.get("mounts").set(index, builder);}
            if (index < 0 || index >= mounts.size()) { mounts.add(builder); } else { mounts.set(index, builder);}
             return (A)this;
    }

    public A addToMounts(io.dekorate.kubernetes.config.Mount... items){
            if (this.mounts == null) {this.mounts = new ArrayList<MountBuilder>();}
            for (io.dekorate.kubernetes.config.Mount item : items) {io.dekorate.kubernetes.config.MountBuilder builder = new io.dekorate.kubernetes.config.MountBuilder(item);_visitables.get("mounts").add(builder);this.mounts.add(builder);} return (A)this;
    }

    public A addAllToMounts(Collection<io.dekorate.kubernetes.config.Mount> items){
            if (this.mounts == null) {this.mounts = new ArrayList<MountBuilder>();}
            for (io.dekorate.kubernetes.config.Mount item : items) {io.dekorate.kubernetes.config.MountBuilder builder = new io.dekorate.kubernetes.config.MountBuilder(item);_visitables.get("mounts").add(builder);this.mounts.add(builder);} return (A)this;
    }

    public A removeFromMounts(io.dekorate.kubernetes.config.Mount... items){
            for (io.dekorate.kubernetes.config.Mount item : items) {io.dekorate.kubernetes.config.MountBuilder builder = new io.dekorate.kubernetes.config.MountBuilder(item);_visitables.get("mounts").remove(builder);if (this.mounts != null) {this.mounts.remove(builder);}} return (A)this;
    }

    public A removeAllFromMounts(Collection<io.dekorate.kubernetes.config.Mount> items){
            for (io.dekorate.kubernetes.config.Mount item : items) {io.dekorate.kubernetes.config.MountBuilder builder = new io.dekorate.kubernetes.config.MountBuilder(item);_visitables.get("mounts").remove(builder);if (this.mounts != null) {this.mounts.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromMounts(io.dekorate.deps.kubernetes.api.builder.Predicate<MountBuilder> predicate){
            if (mounts == null) return (A) this;
            final Iterator<MountBuilder> each = mounts.iterator();
            final List visitables = _visitables.get("mounts");
            while (each.hasNext()) {
              MountBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    public Boolean hasMounts(){
            return mounts != null && !mounts.isEmpty();
    }

    public A addNewMount(String name,String path,String subPath,boolean readOnly){
            return (A)addToMounts(new Mount(name, path, subPath, readOnly));
    }

    public ContainerFluent.MountsNested<A> addNewMount(){
            return new MountsNestedImpl();
    }

    public ContainerFluent.MountsNested<A> addNewMountLike(io.dekorate.kubernetes.config.Mount item){
            return new MountsNestedImpl(-1, item);
    }

    public ContainerFluent.MountsNested<A> setNewMountLike(int index,io.dekorate.kubernetes.config.Mount item){
            return new MountsNestedImpl(index, item);
    }

    public ContainerFluent.MountsNested<A> editMount(int index){
            if (mounts.size() <= index) throw new RuntimeException("Can't edit mounts. Index exceeds size.");
            return setNewMountLike(index, buildMount(index));
    }

    public ContainerFluent.MountsNested<A> editFirstMount(){
            if (mounts.size() == 0) throw new RuntimeException("Can't edit first mounts. The list is empty.");
            return setNewMountLike(0, buildMount(0));
    }

    public ContainerFluent.MountsNested<A> editLastMount(){
            int index = mounts.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last mounts. The list is empty.");
            return setNewMountLike(index, buildMount(index));
    }

    public ContainerFluent.MountsNested<A> editMatchingMount(io.dekorate.deps.kubernetes.api.builder.Predicate<MountBuilder> predicate){
            int index = -1;
            for (int i=0;i<mounts.size();i++) { 
            if (predicate.apply(mounts.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching mounts. No match found.");
            return setNewMountLike(index, buildMount(index));
    }

    public ImagePullPolicy getImagePullPolicy(){
            return this.imagePullPolicy;
    }

    public A withImagePullPolicy(ImagePullPolicy imagePullPolicy){
            this.imagePullPolicy=imagePullPolicy; return (A) this;
    }

    public Boolean hasImagePullPolicy(){
            return this.imagePullPolicy != null;
    }

    
/**
 * This method has been deprecated, please use method buildLivenessProbe instead.
 * @return The buildable object.
 */
@Deprecated public io.dekorate.kubernetes.config.Probe getLivenessProbe(){
            return this.livenessProbe!=null?this.livenessProbe.build():null;
    }

    public io.dekorate.kubernetes.config.Probe buildLivenessProbe(){
            return this.livenessProbe!=null?this.livenessProbe.build():null;
    }

    public A withLivenessProbe(io.dekorate.kubernetes.config.Probe livenessProbe){
            _visitables.get("livenessProbe").remove(this.livenessProbe);
            if (livenessProbe!=null){ this.livenessProbe= new ProbeBuilder(livenessProbe); _visitables.get("livenessProbe").add(this.livenessProbe);} return (A) this;
    }

    public Boolean hasLivenessProbe(){
            return this.livenessProbe != null;
    }

    public ContainerFluent.LivenessProbeNested<A> withNewLivenessProbe(){
            return new LivenessProbeNestedImpl();
    }

    public ContainerFluent.LivenessProbeNested<A> withNewLivenessProbeLike(io.dekorate.kubernetes.config.Probe item){
            return new LivenessProbeNestedImpl(item);
    }

    public ContainerFluent.LivenessProbeNested<A> editLivenessProbe(){
            return withNewLivenessProbeLike(getLivenessProbe());
    }

    public ContainerFluent.LivenessProbeNested<A> editOrNewLivenessProbe(){
            return withNewLivenessProbeLike(getLivenessProbe() != null ? getLivenessProbe(): new ProbeBuilder().build());
    }

    public ContainerFluent.LivenessProbeNested<A> editOrNewLivenessProbeLike(io.dekorate.kubernetes.config.Probe item){
            return withNewLivenessProbeLike(getLivenessProbe() != null ? getLivenessProbe(): item);
    }

    
/**
 * This method has been deprecated, please use method buildReadinessProbe instead.
 * @return The buildable object.
 */
@Deprecated public io.dekorate.kubernetes.config.Probe getReadinessProbe(){
            return this.readinessProbe!=null?this.readinessProbe.build():null;
    }

    public io.dekorate.kubernetes.config.Probe buildReadinessProbe(){
            return this.readinessProbe!=null?this.readinessProbe.build():null;
    }

    public A withReadinessProbe(io.dekorate.kubernetes.config.Probe readinessProbe){
            _visitables.get("readinessProbe").remove(this.readinessProbe);
            if (readinessProbe!=null){ this.readinessProbe= new ProbeBuilder(readinessProbe); _visitables.get("readinessProbe").add(this.readinessProbe);} return (A) this;
    }

    public Boolean hasReadinessProbe(){
            return this.readinessProbe != null;
    }

    public ContainerFluent.ReadinessProbeNested<A> withNewReadinessProbe(){
            return new ReadinessProbeNestedImpl();
    }

    public ContainerFluent.ReadinessProbeNested<A> withNewReadinessProbeLike(io.dekorate.kubernetes.config.Probe item){
            return new ReadinessProbeNestedImpl(item);
    }

    public ContainerFluent.ReadinessProbeNested<A> editReadinessProbe(){
            return withNewReadinessProbeLike(getReadinessProbe());
    }

    public ContainerFluent.ReadinessProbeNested<A> editOrNewReadinessProbe(){
            return withNewReadinessProbeLike(getReadinessProbe() != null ? getReadinessProbe(): new ProbeBuilder().build());
    }

    public ContainerFluent.ReadinessProbeNested<A> editOrNewReadinessProbeLike(io.dekorate.kubernetes.config.Probe item){
            return withNewReadinessProbeLike(getReadinessProbe() != null ? getReadinessProbe(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ContainerFluentImpl that = (ContainerFluentImpl) o;
            if (image != null ? !image.equals(that.image) :that.image != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (envVars != null ? !envVars.equals(that.envVars) :that.envVars != null) return false;
            if (workingDir != null ? !workingDir.equals(that.workingDir) :that.workingDir != null) return false;
            if (command != null ? !command.equals(that.command) :that.command != null) return false;
            if (arguments != null ? !arguments.equals(that.arguments) :that.arguments != null) return false;
            if (ports != null ? !ports.equals(that.ports) :that.ports != null) return false;
            if (mounts != null ? !mounts.equals(that.mounts) :that.mounts != null) return false;
            if (imagePullPolicy != null ? !imagePullPolicy.equals(that.imagePullPolicy) :that.imagePullPolicy != null) return false;
            if (livenessProbe != null ? !livenessProbe.equals(that.livenessProbe) :that.livenessProbe != null) return false;
            if (readinessProbe != null ? !readinessProbe.equals(that.readinessProbe) :that.readinessProbe != null) return false;
            return true;
    }


    public class EnvVarsNestedImpl<N> extends EnvFluentImpl<ContainerFluent.EnvVarsNested<N>> implements ContainerFluent.EnvVarsNested<N>,io.dekorate.deps.kubernetes.api.builder.Nested<N>{

            private final EnvBuilder builder;
        private final int index;
    
            EnvVarsNestedImpl(int index,io.dekorate.kubernetes.config.Env item){
                    this.index = index;
                    this.builder = new EnvBuilder(this, item);
            }
            EnvVarsNestedImpl(){
                    this.index = -1;
                    this.builder = new EnvBuilder(this);
            }
    
    public N and(){
            return (N) ContainerFluentImpl.this.setToEnvVars(index, builder.build());
    }
    public N endEnvVar(){
            return and();
    }

}
    public class PortsNestedImpl<N> extends PortFluentImpl<ContainerFluent.PortsNested<N>> implements ContainerFluent.PortsNested<N>,io.dekorate.deps.kubernetes.api.builder.Nested<N>{

            private final PortBuilder builder;
        private final int index;
    
            PortsNestedImpl(int index,io.dekorate.kubernetes.config.Port item){
                    this.index = index;
                    this.builder = new PortBuilder(this, item);
            }
            PortsNestedImpl(){
                    this.index = -1;
                    this.builder = new PortBuilder(this);
            }
    
    public N and(){
            return (N) ContainerFluentImpl.this.setToPorts(index, builder.build());
    }
    public N endPort(){
            return and();
    }

}
    public class MountsNestedImpl<N> extends MountFluentImpl<ContainerFluent.MountsNested<N>> implements ContainerFluent.MountsNested<N>,io.dekorate.deps.kubernetes.api.builder.Nested<N>{

            private final MountBuilder builder;
        private final int index;
    
            MountsNestedImpl(int index,io.dekorate.kubernetes.config.Mount item){
                    this.index = index;
                    this.builder = new MountBuilder(this, item);
            }
            MountsNestedImpl(){
                    this.index = -1;
                    this.builder = new MountBuilder(this);
            }
    
    public N and(){
            return (N) ContainerFluentImpl.this.setToMounts(index, builder.build());
    }
    public N endMount(){
            return and();
    }

}
    public class LivenessProbeNestedImpl<N> extends ProbeFluentImpl<ContainerFluent.LivenessProbeNested<N>> implements ContainerFluent.LivenessProbeNested<N>,io.dekorate.deps.kubernetes.api.builder.Nested<N>{

            private final ProbeBuilder builder;
    
            LivenessProbeNestedImpl(io.dekorate.kubernetes.config.Probe item){
                    this.builder = new ProbeBuilder(this, item);
            }
            LivenessProbeNestedImpl(){
                    this.builder = new ProbeBuilder(this);
            }
    
    public N and(){
            return (N) ContainerFluentImpl.this.withLivenessProbe(builder.build());
    }
    public N endLivenessProbe(){
            return and();
    }

}
    public class ReadinessProbeNestedImpl<N> extends ProbeFluentImpl<ContainerFluent.ReadinessProbeNested<N>> implements ContainerFluent.ReadinessProbeNested<N>,io.dekorate.deps.kubernetes.api.builder.Nested<N>{

            private final ProbeBuilder builder;
    
            ReadinessProbeNestedImpl(io.dekorate.kubernetes.config.Probe item){
                    this.builder = new ProbeBuilder(this, item);
            }
            ReadinessProbeNestedImpl(){
                    this.builder = new ProbeBuilder(this);
            }
    
    public N and(){
            return (N) ContainerFluentImpl.this.withReadinessProbe(builder.build());
    }
    public N endReadinessProbe(){
            return and();
    }

}


}
